==> bonita-server-8.0.0-sources.jar: org/bonitasoft/engine/api/impl/PermissionAPIImpl.java <==
/**
 * Copyright (C) 2019 Bonitasoft S.A.
 * Bonitasoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.api.impl;

import java.util.Set;

import lombok.extern.slf4j.Slf4j;
import org.bonitasoft.engine.api.PermissionAPI;
import org.bonitasoft.engine.api.permission.APICallContext;
import org.bonitasoft.engine.authorization.PermissionService;
import org.bonitasoft.engine.commons.exceptions.SExecutionException;
import org.bonitasoft.engine.exception.ExecutionException;
import org.bonitasoft.engine.exception.NotFoundException;
import org.bonitasoft.engine.service.TenantServiceAccessor;
import org.bonitasoft.engine.service.TenantServiceSingleton;

/**
 * @author Baptiste Mesta
 */
@Slf4j
public class PermissionAPIImpl implements PermissionAPI {

    @Override
    @Deprecated(forRemoval = true, since = "7.14.0")
    public boolean checkAPICallWithScript(String className, APICallContext context, boolean reload)
            throws ExecutionException, NotFoundException {
        TenantServiceAccessor serviceAccessor = getTenantServiceAccessor();
        PermissionService permissionService = serviceAccessor.getPermissionService();
        try {
            return permissionService.checkAPICallWithScript(className, context, reload);
        } catch (SExecutionException e) {
            throw new ExecutionException(
                    "Unable to execute the security rule " + className + " for the api call " + context, e);
        } catch (ClassNotFoundException e) {
            throw new NotFoundException("Unable to execute the security rule " + className + " for the api call "
                    + context + " because the class " + className + " is not found", e);
        }
    }

    @Override
    public boolean isAuthorized(APICallContext apiCallContext) throws ExecutionException {
        TenantServiceAccessor serviceAccessor = getTenantServiceAccessor();
        try {
            return serviceAccessor.getPermissionService().isAuthorized(apiCallContext);
        } catch (SExecutionException e) {
            throw new ExecutionException(e);
        }
    }

    @Override
    public Set<String> getResourcePermissions(String resourceKey) {
        TenantServiceAccessor serviceAccessor = getTenantServiceAccessor();
        return serviceAccessor.getPermissionService().getResourcePermissions(resourceKey);
    }

    TenantServiceAccessor getTenantServiceAccessor() {
        return TenantServiceSingleton.getInstance();
    }

}

==> bonita-server-9.0.0-sources.jar: org/bonitasoft/engine/api/impl/PermissionAPIImpl.java <==
/**
 * Copyright (C) 2019 Bonitasoft S.A.
 * Bonitasoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.api.impl;

import java.util.Set;

import lombok.extern.slf4j.Slf4j;
import org.bonitasoft.engine.api.PermissionAPI;
import org.bonitasoft.engine.api.permission.APICallContext;
import org.bonitasoft.engine.authorization.PermissionService;
import org.bonitasoft.engine.commons.exceptions.SExecutionException;
import org.bonitasoft.engine.exception.ExecutionException;
import org.bonitasoft.engine.exception.NotFoundException;
import org.bonitasoft.engine.service.ServiceAccessor;
import org.bonitasoft.engine.service.ServiceAccessorSingleton;

/**
 * @author Baptiste Mesta
 */
@Slf4j
@AvailableWhenTenantIsPaused
public class PermissionAPIImpl implements PermissionAPI {

    @Override
    @Deprecated(forRemoval = true, since = "7.14.0")
    public boolean checkAPICallWithScript(String className, APICallContext context, boolean reload)
            throws ExecutionException, NotFoundException {
        ServiceAccessor serviceAccessor = getServiceAccessor();
        PermissionService permissionService = serviceAccessor.getPermissionService();
        try {
            return permissionService.checkAPICallWithScript(className, context, reload);
        } catch (SExecutionException e) {
            throw new ExecutionException(
                    "Unable to execute the security rule " + className + " for the api call " + context, e);
        } catch (ClassNotFoundException e) {
            throw new NotFoundException("Unable to execute the security rule " + className + " for the api call "
                    + context + " because the class " + className + " is not found", e);
        }
    }

    @Override
    public boolean isAuthorized(APICallContext apiCallContext) throws ExecutionException {
        ServiceAccessor serviceAccessor = getServiceAccessor();
        try {
            return serviceAccessor.getPermissionService().isAuthorized(apiCallContext);
        } catch (SExecutionException e) {
            throw new ExecutionException(e);
        }
    }

    @Override
    public Set<String> getResourcePermissions(String resourceKey) {
        ServiceAccessor serviceAccessor = getServiceAccessor();
        return serviceAccessor.getPermissionService().getResourcePermissions(resourceKey);
    }

    ServiceAccessor getServiceAccessor() {
        return ServiceAccessorSingleton.getInstance();
    }

}
